==> imdb-movie-1.6.7.tgz: package/services/dataService.js <==
"use strict";

// let kue = require("kue");
// let queue = kue.createQueue();

const serverBaseUrl = "https://renjer-imdb.herokuapp.com"

let testFile = "./testFile/";
let fs = require("fs");
let axios = require("axios");
let request = require("request");
let imdb = require('imdb-api');
let download = require('image-downloader')

//get movie imdb information
// function getMovieInfo(movieName) {
//     return axios({
//         method: 'GET',
//         url: baseUrl + movieName + "&apikey=4a03ae5d",
//         headers: {
//             "content-Type": "application/json",
//         }
//       
//     })
// }

// get movie imdb information
function getMovieInfoFromOurServers(movieName) {
    return axios.get(serverBaseUrl +"/movies/movie", {
        params:{
            movieName
        }
    }).then(function (result) {
        let movie = result.data;
            console.log("movie info received ", movie.title);

            return movie
        })
        .catch(function (error) {
            console.log("err getMovieInfo:", error.message)
        });
}


////download movie_poster by its name
function downloadImageByPhotoLink(posterLink
    , dest) {
    let options = {
        url: serverBaseUrl +"/movies/poster?poster="+posterLink
        , dest: dest
    }

    return download.image(options)
        .then(({filename, image}) => {
            console.log('File saved to', filename)
        }).catch((err) => {
            console.log('downloadImageByPhotoLink err:', err)
        })

}


//read all the files_name and save them in a array
function getMovieFileName(filesInfo) {

}

function makeFileAndPutSthInIt(movieInfo, dir) {
    fs.writeFileSync(dir + '/info.txt', JSON.stringify(movieInfo, null, 4));
    fs.writeFileSync(dir + '/cover.jpg');
    return downloadImageByPhotoLink(movieInfo.poster, dir + '/cover.jpg')
        .then(res => {
            console.log("cover image downloaded successfully  : ", movieInfo.title);
        }).catch(err =>{
            console.log("error downloading images   : ", err);
            return Promise.reject();
        })
}


//rename files
function renameMovieFiles(movieNewFileName, movieFileName) {


}


module.exports = {
    downloadImageByPhotoLink,
    getMovieFileName,
    renameMovieFiles,
    makeFileAndPutSthInIt,
    getMovieInfoFromOurServers
};

==> imdb-movie-1.7.10.tgz: package/services/dataService.js <==
"use strict";

// let kue = require("kue");
// let queue = kue.createQueue();

// const serverBaseUrl = "http://localhost:4000"
const serverBaseUrl = "https://renjer-imdb.herokuapp.com"
let fs = require("fs");
const axios = require("axios");
let download = require('image-downloader')

//get movie imdb information
// function getMovieInfo(movieName) {
//     return axios({
//         method: 'GET',
//         url: baseUrl + movieName + "&apikey=4a03ae5d",
//         headers: {
//             "content-Type": "application/json",
//         }
//       
//     })
// }

// get movie imdb information
async function getMovieInfoFromOurServers(title, year) {
    const params =  {
        title
    }
    if (year && year.length === 4){
        params.year = year
    }
    const result = await axios.get(serverBaseUrl + "/movies", {
        params
    })
    return result.data

}


////download movie_poster by its name
function downloadImageByPhotoLink(posterLink
    , dest) {
    let options = {
        url: serverBaseUrl + "/movies/poster?imageLink=" + posterLink
        , dest: dest
    }

    return download.image(options)
        .then(({filename, image}) => {
            console.log('File saved to', filename)
        }).catch((err) => {
            console.log('downloadImageByPhotoLink err:', err)
        })

}


//read all the files_name and save them in a array
function getMovieFileName(filesInfo) {

}

function makeFileAndPutSthInIt(movieInfo, dir) {
    fs.writeFileSync(dir + '/info.txt', JSON.stringify(movieInfo, null, 4));
    fs.writeFileSync(dir + '/cover.jpg');
    return downloadImageByPhotoLink(movieInfo.poster, dir + '/cover.jpg')
        .then(res => {
            console.log("cover image downloaded successfully  : ", movieInfo.title);
        }).catch(err => {
            console.log("error downloading images   : ", err);
            return Promise.reject();
        })
}


//rename files
function renameMovieFiles(movieNewFileName, movieFileName) {


}


module.exports = {
    downloadImageByPhotoLink,
    getMovieFileName,
    renameMovieFiles,
    makeFileAndPutSthInIt,
    getMovieInfoFromOurServers
};
